PaymentWebhookResult class

Resultado de POST /webhooks/payments.

Constructors

PaymentWebhookResult({required bool credited, bool? idempotent, String? paymentId, String? walletId, num? amount, num? balanceAfter, String? status, String? message, Map<String, dynamic> raw = const {}})
const
PaymentWebhookResult.fromJson(Map<String, dynamic> json)
factory

Properties

amount num?
final
balanceAfter num?
final
credited bool
final
hashCode int
The hash code for this object.
no setterinherited
idempotent bool?
final
message String?
final
paymentId String?
final
raw Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
walletId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited