PaymentWebhookSigner class

Alias legado.

Constructors

PaymentWebhookSigner({required String secret, int maxSkewMs = 300000})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxSkewMs int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secret String
final

Methods

buildHeaders({required String paymentId, required num amount, required String externalUserId, required String status, int? timestampMs}) Map<String, String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign({required Object timestamp, required String paymentId, required num amount, required String externalUserId, required String status}) String
toString() String
A string representation of this object.
inherited
verify({required Object timestamp, required String paymentId, required num amount, required String externalUserId, required String status, required String signature, int? nowMs}) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited