PaymentsClient class

Cliente server-only para top-ups (PAYMENTS_API_KEY / HMAC).

Nunca use na app móvel. Import via package:moveme_wallet/payments.dart.

Constructors

PaymentsClient({required PaymentsClientOptions options, Client? httpClient})
PaymentsClient.raw({required PaymentsClientOptions options, required WalletHttp http})

Properties

hashCode int
The hash code for this object.
no setterinherited
options PaymentsClientOptions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
load({String? walletId, String? externalUserId, required num amount, required String paymentId, String provider = 'manual', String? details}) Future<WalletLoad>
POST /api/digital-wallet/loads
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendWebhook({required String paymentId, required num amount, required String externalUserId, String status = 'paid', String provider = 'generic', int? timestamp, String? signature, String? webhookSecret}) Future<PaymentWebhookResult>
POST /api/digital-wallet/webhooks/payments
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited