PaymentsClientOptions class

Opções do PaymentsClientbackend only.

Constructors

PaymentsClientOptions({required String baseUrl, required String paymentsApiKey, Duration timeout = const Duration(milliseconds: 15000), String pathPrefix = WalletEndpoints.prefix})
const
PaymentsClientOptions.local({required String paymentsApiKey, String baseUrl = 'http://127.0.0.1:3123', Duration timeout = const Duration(milliseconds: 15000)})
factory
PaymentsClientOptions.production({required String paymentsApiKey, String baseUrl = 'https://wsup.appmoveme.com', Duration timeout = const Duration(milliseconds: 15000)})
factory

Properties

baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
pathPrefix String
final
paymentsApiKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited