WalletLoad class
Resultado de POST /loads.
Constructors
Properties
- amount → num
-
final
- balanceAfter → num?
-
final
- creditTxId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idempotent → bool
-
final
- loadId → String
-
final
- ok → bool
-
final
- paymentId → String
-
final
- provider → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- walletId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited