WalletNetworkError class
Rede / timeout.
- Inheritance
-
- Object
- WalletApiError
- WalletNetworkError
Constructors
- WalletNetworkError(String message, {Object? cause})
Properties
- amountDue → num?
-
no setterinherited
- apiCode → String?
-
Código de negócio da API (ex.
ADVANCE_ALREADY_OPEN).finalinherited - body → Object?
-
finalinherited
- cause → Object?
-
final
- code → WalletErrorCode
-
finalinherited
- details → List?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConflict → bool
-
no setterinherited
- isForbidden → bool
-
no setterinherited
- isNotFound → bool
-
no setterinherited
- isRateLimited → bool
-
no setterinherited
- isServerError → bool
-
no setterinherited
-
no setterinherited
-
no setterinherited
- isValidation → bool
-
no setterinherited
- message → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited